<?php

class ArrayPieceSquadro implements ArrayAccess, Countable {
    private $pieces = [];

    // Méthode pour vérifier si un offset existe (compatible avec ArrayAccess)
    public function offsetExists($offset): bool {
        return isset($this->pieces[$offset]);
    }

    // Méthode pour récupérer une pièce à un offset donné (compatible avec ArrayAccess)
    public function offsetGet(mixed $index): mixed {
      if (!array_key_exists($index, $this->pieces)) {
          return null; // Retourne NULL au lieu de lever une exception
      }
      return $this->pieces[$index];
  }




    // Méthode pour définir une pièce à un offset donné (compatible avec ArrayAccess)
    public function offsetSet($offset, $value): void {
    if (!$value instanceof PieceSquadro) {
        throw new InvalidArgumentException("Value must be an instance of PieceSquadro.");
    }
    if (is_null($offset)) {
        $this->pieces[] = $value; // Ajoute à la fin du tableau si l'offset est null
    } else {
        // Convertir $offset en entier si ce n'est pas déjà le cas
        $offset = (int)$offset;
        if ($offset < 0) {
            throw new OutOfBoundsException("Offset invalide : l'index doit être un entier positif.");
        }
        $this->pieces[$offset] = $value; // Définit la valeur à l'offset spécifié
    }
}

    // Méthode pour supprimer une pièce à un offset donné (compatible avec ArrayAccess)
    public function offsetUnset($offset): void {
        if (!$this->offsetExists($offset)) {
            throw new OutOfBoundsException("Offset invalide : l'index $offset n'existe pas.");
        }
        unset($this->pieces[$offset]);
        $this->pieces = array_values($this->pieces); // Réindexe le tableau
    }

    // Méthode pour compter le nombre de pièces (compatible avec Countable)
    public function count(): int {
        return count($this->pieces);
    }

    // Méthode pour ajouter une pièce au tableau
    public function add(PieceSquadro $piece): void {
        $this->pieces[] = $piece;
    }

    // Méthode pour supprimer une pièce à un index donné
    public function remove(int $index): void {
        if (!$this->offsetExists($index)) {
            throw new OutOfBoundsException("Index invalide : l'index $index n'existe pas.");
        }
        unset($this->pieces[$index]);
        $this->pieces = array_values($this->pieces); // Réindexe le tableau
    }

    // Méthode pour convertir le tableau de pièces en JSON
    public function toJson(): string {
        return json_encode(array_map(function($piece) {
            return $piece->toJson();
        }, $this->pieces));
    }

    // Méthode pour créer une instance de ArrayPieceSquadro à partir d'un JSON
    public static function fromJson(string $json): self {
        $data = json_decode($json, true);
        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new InvalidArgumentException("JSON invalide.");
        }
        $array = new self();
        foreach ($data as $pieceJson) {
            if (!is_array($pieceJson) || !isset($pieceJson['couleur']) || !isset($pieceJson['direction'])) {
                throw new InvalidArgumentException("JSON invalide : chaque élément doit être une pièce valide.");
            }
            $array->add(PieceSquadro::fromJson(json_encode($pieceJson)));
        }
        return $array;
    }
}
?>
