<?php

class PieceSquadro {
    const BLANC = 0;
    const NOIR = 1;
    const VIDE = 2;
    const NEUTRE = 3;
    const NORD = 4;
    const EST = 5;
    const SUD = 6;
    const OUEST = 7;

    private $couleur;
    private $direction;

    private function __construct($couleur, $direction) {
        if (!in_array($couleur, [self::BLANC, self::NOIR, self::VIDE, self::NEUTRE])) {
            throw new InvalidArgumentException("Couleur invalide.");
        }
        if (!in_array($direction, [self::NORD, self::EST, self::SUD, self::OUEST])) {
            throw new InvalidArgumentException("Direction invalide.");
        }
        $this->couleur = $couleur;
        $this->direction = $direction;
    }

    public static function initVide() {
        return new self(self::VIDE, self::NORD);
    }

    public static function initNoirNord() {
        return new self(self::NOIR, self::NORD);
    }

    public static function initNoirSud() {
        return new self(self::NOIR, self::SUD);
    }

    public static function initBlancEst() {
        return new self(self::BLANC, self::EST);
    }

    public static function initBlancOuest() {
        return new self(self::BLANC, self::OUEST);
    }

    public function getCouleur() {
        return $this->couleur;
    }

    public function getDirection() {
        return $this->direction;
    }

    public function calculateNextMove($x, $y) {
        switch ($this->direction) {
            case self::NORD:
                return [$x, $y - 1]; // Monte
            case self::SUD:
                return [$x, $y + 1]; // Descend
            case self::EST:
                return [$x + 1, $y]; // Va à droite
            case self::OUEST:
                return [$x - 1, $y]; // Va à gauche
            default:
                return [$x, $y]; // Pas de mouvement si direction inconnue
        }
    }

    public function inverseDirection() {
        if ($this->direction === self::NORD || $this->direction === self::SUD) {
            $this->direction = ($this->direction === self::NORD) ? self::SUD : self::NORD;
        } elseif ($this->direction === self::EST || $this->direction === self::OUEST) {
            $this->direction = ($this->direction === self::EST) ? self::OUEST : self::EST;
        } else {
            throw new LogicException("Direction invalide à inverser.");
        }
    }

    public function toJson() {
        return json_encode(['couleur' => $this->couleur, 'direction' => $this->direction]);
    }

    public static function fromJson($json) {
        $data = json_decode($json, true);
        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new InvalidArgumentException("JSON invalide.");
        }
        return new self($data['couleur'], $data['direction']);
    }
}
?>
