<?php
require_once 'ArrayPieceSquadro.php';
require_once 'PieceSquadro.php';

class PlateauSquadro {
    const BLANC_V_ALLER = [1, 3, 2, 3, 1];
    const BLANC_V_RETOUR = [3, 1, 2, 1, 3];
    const NOIR_V_ALLER = [3, 1, 2, 1, 3];
    const NOIR_V_RETOUR = [1, 3, 2, 3, 1];

    private $plateau = [];

    public function __construct() {
        $this->initCasesVides();
        $this->initCasesBlanches();
        $this->initCasesNoires();
    }

    // Initialise toutes les cases vides
    private function initCasesVides() {
        for ($i = 0; $i < 9; $i++) {
            $this->plateau[$i] = [];
            for ($j = 0; $j < 9; $j++) {
                $this->plateau[$i][$j] = PieceSquadro::initVide();
            }
        }
    }

    private function initCasesBlanches() {
        for ($y = 2; $y <= 6; $y++) { // Lignes jouables : 2 à 6
            $this->plateau[1][$y] = PieceSquadro::initBlancOuest(); // Colonne 1 (Ouest)
        }
    }
    
    private function initCasesNoires() {
        for ($x = 2; $x <= 6; $x++) {
            $this->plateau[$x][8] = PieceSquadro::initNoirSud(); // Ligne 8 (Sud)
        }
    }

    // Récupère une pièce à partir des coordonnées (x, y)
    public function getPiece($x, $y) {
        if ($x < 0 || $x >= 9 || $y < 0 || $y >= 9) {
            return null; // Hors limites du plateau
        }
        return $this->plateau[$x][$y];
    }

    // Définit une pièce à une position donnée (x, y)
    public function setPiece($piece, $x, $y) {
        if ($x < 0 || $y < 0 || $x >= 9 || $y >= 9) {
            throw new OutOfBoundsException("Coordonnées invalides.");
        }
        $this->plateau[$x][$y] = $piece;
    }

    // Calcule la destination d'une pièce en fonction de sa position et de sa direction
    public function getCoordDestination($x, $y) {
        $piece = $this->getPiece($x, $y);
        if (!$piece || $piece->getCouleur() === PieceSquadro::VIDE) {
            return [$x, $y]; // Pas de mouvement si la case est vide
        }
    
        $direction = $piece->getDirection();
        $couleur = $piece->getCouleur();
    
        if ($couleur === PieceSquadro::BLANC) {
            if ($direction === PieceSquadro::OUEST) {
                $speed = self::BLANC_V_ALLER[$y - 2]; // Vitesse basée sur la ligne (y)
                return [$x + $speed, $y];
            } elseif ($direction === PieceSquadro::EST) {
                $speed = self::BLANC_V_RETOUR[$y - 2]; // Vitesse basée sur la ligne (y)
                return [$x - $speed, $y];
            }
        } elseif ($couleur === PieceSquadro::NOIR) {
            if ($direction === PieceSquadro::SUD) {
                $speed = self::NOIR_V_ALLER[$x - 2]; // Vitesse basée sur la colonne (x)
                return [$x, $y - $speed];
            } elseif ($direction === PieceSquadro::NORD) {
                $speed = self::NOIR_V_RETOUR[$x - 2]; // Vitesse basée sur la colonne (x)
                return [$x, $y + $speed];
            }
        }
    
        return [$x, $y]; // Aucun mouvement si la direction est invalide
    }

    // Vérifie si une pièce atteint un point de retournement
    public function isTurningPoint($x, $y) {
        $piece = $this->getPiece($x, $y);
        if (!$piece || $piece->getCouleur() === PieceSquadro::VIDE) {
            return false;
        }

        $couleur = $piece->getCouleur();
        $direction = $piece->getDirection();

        if ($couleur === PieceSquadro::BLANC && $direction === PieceSquadro::OUEST && $x === 6) {
            return true;
        }
        if ($couleur === PieceSquadro::BLANC && $direction === PieceSquadro::EST && $x === 2) {
            return true;
        }
        if ($couleur === PieceSquadro::NOIR && $direction === PieceSquadro::SUD && $y === 2) {
            return true;
        }
        if ($couleur === PieceSquadro::NOIR && $direction === PieceSquadro::NORD && $y === 6) {
            return true;
        }

        return false;
    }

    // Inverse la direction d'une pièce
    public function inverseDirection($x, $y) {
        $piece = $this->getPiece($x, $y);
        if ($piece && $piece->getCouleur() !== PieceSquadro::VIDE) {
            $piece->inverseDirection();
            $this->setPiece($piece, $x, $y);
        }
    }

    // Vérifie si une pièce sort du plateau
    public function isOutOfBoard($x, $y) {
        return $x < 0 || $x >= 9 || $y < 0 || $y >= 9;
    }
}
?>