<?php
require_once 'PieceSquadroUI.php';

class SquadroUIGenerator {
    public static function generateGamePage($activePlayerColor = 'white') {
        if (!in_array($activePlayerColor, ['white', 'black'])) {
            $activePlayerColor = 'white';
        }

        $html = "
        <!DOCTYPE html>
        <html lang='fr'>
        <head>
            <meta charset='UTF-8'>
            <title>Squadro - Jeu de Société</title>
            <link rel='stylesheet' href='styles.css'>
        </head>
        <body>
            <div class='title'>Squadro</div>
            <div class='status'>Au tour du joueur " . ucfirst($activePlayerColor) . "</div>
            <div class='board'>
                " . self::generateRow(['', '', '3', '1', '2', '1', '3', '', ''], false, 0) . " <!-- Ligne supérieure -->
                " . self::generateRow(['', 'L', 'N', 'N', 'N', 'N', 'N', 'L', ''], false, 1) . " <!-- Indicateurs Nord -->
                " . self::generateRow(['1', 'W', 'V', 'V', 'V', 'V', 'V', 'E', '3'], $activePlayerColor === 'white', 2) . " <!-- Pièces blanches Ouest -->
                " . self::generateRow(['3', 'W', 'V', 'V', 'V', 'V', 'V', 'E', '1'], $activePlayerColor === 'white', 3) . "
                " . self::generateRow(['2', 'W', 'V', 'V', 'V', 'V', 'V', 'E', '2'], $activePlayerColor === 'white', 4) . "
                " . self::generateRow(['3', 'W', 'V', 'V', 'V', 'V', 'V', 'E', '1'], $activePlayerColor === 'white', 5) . "
                " . self::generateRow(['1', 'W', 'V', 'V', 'V', 'V', 'V', 'E', '3'], $activePlayerColor === 'white', 6) . "
                " . self::generateRow(['', 'L', 'B', 'B', 'B', 'B', 'B', 'L', ''], false, 7) . " <!-- Pièces noires sur les cases Sud -->
                " . self::generateRow(['', '', '1', '3', '2', '3', '1', '', ''], false, 8) . " <!-- Ligne inférieure vide -->
            </div>
        </body>
        </html>
        ";
        return $html;
    }
    
    private static function generateRow($cells, $isPlayable, $y) {
        $html = "";
        $x = 0; // Coordonnée horizontale
    
        foreach ($cells as $cell) {
            if ($cell === '') {
                // Cases neutres (rouge ou crème selon la position)
                if ($x == 0 || $x == 8 || $y == 0 || $y == 8) {
                    $html .= '<button class="cell Corner"></button>'; // Coins extérieurs : fond crème
                } else {
                    $html .= '<button class="cell Limites"></button>'; // Autres cases neutres : fond rouge
                }
            } elseif ($cell === 'L') {
                // Cases limites (gris foncé pour les coins spécifiques)
                if (($x == 1 && $y == 1) || ($x == 1 && $y == 7) || ($x == 7 && $y == 1) || ($x == 7 && $y == 7)) {
                    $html .= '<button class="cell Limites DarkLimit"></button>'; // Coins spécifiques : fond gris foncé
                } else {
                    $html .= '<button class="cell Limites"></button>'; // Autres limites : fond rouge
                }
            } elseif (in_array($cell, ['O', 'N', 'S', 'E'])) {
                // Indicateurs directionnels (fond crème)
                $html .= '<button class="cell Direction"></button>';
            } elseif (is_numeric($cell)) {
                // Cases avec chiffres (fond vert)
                $html .= '<button class="cell speed-cell">' . htmlspecialchars($cell) . '</button>';
            } elseif ($cell === 'V') {
                // Cases valides (bleu ciel très clair)
                $html .= '<button class="cell CaseValide"></button>';
            } elseif ($cell === 'W') { // Pièce blanche Ouest
                $html .= PieceSquadroUI::generatePieceCell('white', $x, $y, $isPlayable);
            } elseif ($cell === 'B') { // Pièce noire Sud
                $html .= PieceSquadroUI::generatePieceCell('black', $x, $y, !$isPlayable);
            } else {
                // Par défaut : case vide (gris)
                $html .= '<button class="cell"></button>';
            }
    
            $x++; // Incrémenter la colonne
        }
    
        return $html;
    }

    public static function generateConfirmationPage($x, $y) {
        $html = "
        <!DOCTYPE html>
        <html lang='fr'>
        <head>
            <meta charset='UTF-8'>
            <title>Confirmation</title>
            <style>
                /* Styles restent inchangés */
            </style>
        </head>
        <body>
            <h1>Voulez-vous déplacer la pièce située en ($x, $y) ?</h1>
            <a href='move.php?x=$x&y=$y'><button class='yes'>Oui</button></a>
            <a href='index.php'><button class='no'>Non</button></a>
        </body>
        </html>
        ";
        return $html;
    }

    public static function generateVictoryPage($winnerColor) {
        $html = "
        <!DOCTYPE html>
        <html lang='fr'>
        <head>
            <meta charset='UTF-8'>
            <title>Victoire</title>
            <style>
                body {
                    display: flex;
                    flex-direction: column;
                    align-items: center;
                    font-family: Arial, sans-serif;
                    background-color: #f5f5f5;
                }
                h1 {
                    font-size: 2em;
                    margin: 20px 0;
                }
                a {
                    font-size: 1.2em;
                    color: blue;
                    text-decoration: none;
                }
            </style>
        </head>
        <body>
            <h1>Victoire !</h1>
            <p>Le joueur " . ucfirst($winnerColor) . " a gagné la partie.</p>
            <a href='game.php'>Rejouer</a>
        </body>
        </html>
        ";
        return $html;
    }
}
?>